@@ -11,6 +11,7 @@ from .schema import BLANK_SCHEMA  # noqa
 from .schema import CheckConstraint  # noqa
 from .schema import Column  # noqa
 from .schema import ColumnDefault  # noqa
+from .schema import Computed  # noqa
 from .schema import Constraint  # noqa
 from .schema import DDL  # noqa
 from .schema import DefaultClause  # noqa
@@ -122,7 +123,7 @@ from .engine import create_engine  # noqa nosort
 from .engine import engine_from_config  # noqa nosort
 
 
-__version__ = '1.3.8'
+__version__ = "1.3.11"
 
 
 def __go(lcls):
